@@ -112,7 +112,7 @@ static void readLocaleSettings()
     *lDateSep = "-";
     *lTimeSep = ":";
 #endif
-    TQString d = ExtDate( 1999, 11, 22 ).toString( Qt::LocalDate );
+    TQString d = ExtDate( 1999, 11, 22 ).toString( TQt::LocalDate );
     dpos = d.find( "22" );
     mpos = d.find( "11" );
     ypos = d.find( "99" );
@@ -142,7 +142,7 @@ static void readLocaleSettings()
     }
 
 #ifndef TQ_WS_WIN
-    TQString t = TQTime( 11, 22, 33 ).toString( Qt::LocalDate );
+    TQString t = TQTime( 11, 22, 33 ).toString( TQt::LocalDate );
     dpos = t.find( "11" );
     mpos = t.find( "22" );
     ypos = t.find( "33" );
@@ -497,9 +497,9 @@ bool ExtDateTimeEditor::eventFilter( TQObject *o, TQEvent *e )
 		cw->stepDown();
 		return TRUE;
 	    case Key_Backspace:
-		if ( ::tqqt_cast<ExtDateEdit*>(cw) )
+		if ( ::tqt_cast<ExtDateEdit*>(cw) )
 		    ((ExtDateEdit*)cw)->removeFirstNumber( d->focusSection() );
-		else if ( ::tqqt_cast<TQTimeEdit*>(cw) )
+		else if ( ::tqt_cast<TQTimeEdit*>(cw) )
 		    ((TQTimeEdit*)cw)->removeFirstNumber( d->focusSection() );
 		return TRUE;
 	    case Key_Delete:
@@ -513,15 +513,15 @@ bool ExtDateTimeEditor::eventFilter( TQObject *o, TQEvent *e )
 		TQWidget *w = this;
 		bool hadDateEdit = FALSE;
 		while ( w ) {
-		    if ( ::tqqt_cast<ExtDateTimeSpinWidget*>(w) && qstrcmp( w->name(), "qt_spin_widget" ) != 0 ||
-			 ::tqqt_cast<ExtDateTimeEdit*>(w) )
+		    if ( ::tqt_cast<ExtDateTimeSpinWidget*>(w) && qstrcmp( w->name(), "qt_spin_widget" ) != 0 ||
+			 ::tqt_cast<ExtDateTimeEdit*>(w) )
 			break;
-		    hadDateEdit = hadDateEdit || ::tqqt_cast<ExtDateEdit*>(w);
+		    hadDateEdit = hadDateEdit || ::tqt_cast<ExtDateEdit*>(w);
 		    w = w->parentWidget();
 		}
 
 		if ( w ) {
-		    if ( !::tqqt_cast<ExtDateTimeEdit*>(w) ) {
+		    if ( !::tqt_cast<ExtDateTimeEdit*>(w) ) {
 			w = w->parentWidget();
 		    } else {
 			ExtDateTimeEdit *ed = (ExtDateTimeEdit*)w;
@@ -532,7 +532,7 @@ bool ExtDateTimeEditor::eventFilter( TQObject *o, TQEvent *e )
 			    ed->dateEdit()->setFocus();
 			    return TRUE;
 			} else {
-			    while ( w && !::tqqt_cast<ExtDateTimeEdit*>(w) )
+			    while ( w && !::tqt_cast<ExtDateTimeEdit*>(w) )
 				w = w->parentWidget();
 			}
 		    }
@@ -550,7 +550,7 @@ bool ExtDateTimeEditor::eventFilter( TQObject *o, TQEvent *e )
 			    repaint( rect(), FALSE );
 		    }
 		    return TRUE;
-		} else if ( !txt.isEmpty() && ::tqqt_cast<TQTimeEdit*>(cw) && focusSection() == (int) d->sectionCount()-1 ) {
+		} else if ( !txt.isEmpty() && ::tqt_cast<TQTimeEdit*>(cw) && focusSection() == (int) d->sectionCount()-1 ) {
 		    // the first character of the AM/PM indicator toggles if the section has focus
 		    TQTimeEdit *te = (TQTimeEdit*)cw;
 		    TQTime time = te->time();
@@ -830,10 +830,10 @@ void ExtDateEdit::init()
   d->ed = new ExtDateTimeEditor( this, "date editor" );
   d->controls->setEditWidget( d->ed );
   setFocusProxy( d->ed );
-  connect( d->controls, TQT_SIGNAL( stepUpPressed() ), TQT_SLOT( stepUp() ) );
-  connect( d->controls, TQT_SIGNAL( stepDownPressed() ), TQT_SLOT( stepDown() ) );
-  connect( this, TQT_SIGNAL( valueChanged(const ExtDate&) ),
-      TQT_SLOT( updateButtons() ) );
+  connect( d->controls, TQ_SIGNAL( stepUpPressed() ), TQ_SLOT( stepUp() ) );
+  connect( d->controls, TQ_SIGNAL( stepDownPressed() ), TQ_SLOT( stepDown() ) );
+  connect( this, TQ_SIGNAL( valueChanged(const ExtDate&) ),
+      TQ_SLOT( updateButtons() ) );
   d->ed->appendSection( TQNumberSection( 0,4 ) );
   d->ed->appendSection( TQNumberSection( 5,7 ) );
   d->ed->appendSection( TQNumberSection( 8,10 ) );
@@ -1740,8 +1740,8 @@ public:
 //     d->controls = new ExtDateTimeSpinWidget( this, qstrcmp( name(), "qt_datetime_timeedit" ) == 0 ? "qt_spin_widget" : "time edit controls" );
 //     d->controls->setEditWidget( d->ed );
 //     setFocusProxy( d->ed );
-//     connect( d->controls, TQT_SIGNAL( stepUpPressed() ), TQT_SLOT( stepUp() ) );
-//     connect( d->controls, TQT_SIGNAL( stepDownPressed() ), TQT_SLOT( stepDown() ) );
+//     connect( d->controls, TQ_SIGNAL( stepUpPressed() ), TQ_SLOT( stepUp() ) );
+//     connect( d->controls, TQ_SIGNAL( stepDownPressed() ), TQ_SLOT( stepDown() ) );
 //
 //     d->ed->appendSection( TQNumberSection( 0,0, TRUE, 0 ) );
 //     d->ed->appendSection( TQNumberSection( 0,0, TRUE, 1 ) );
@@ -2610,10 +2610,10 @@ void ExtDateTimeEdit::init()
     de = new ExtDateEdit( this, "qt_datetime_dateedit" );
     te = new TQTimeEdit( this, "qt_datetime_timeedit" );
     d->adv = FALSE;
-    connect( de, TQT_SIGNAL( valueChanged( const ExtDate& ) ),
-	     this, TQT_SLOT( newValue( const ExtDate& ) ) );
-    connect( te, TQT_SIGNAL( valueChanged( const TQTime& ) ),
-	     this, TQT_SLOT( newValue( const TQTime& ) ) );
+    connect( de, TQ_SIGNAL( valueChanged( const ExtDate& ) ),
+	     this, TQ_SLOT( newValue( const ExtDate& ) ) );
+    connect( te, TQ_SIGNAL( valueChanged( const TQTime& ) ),
+	     this, TQ_SLOT( newValue( const TQTime& ) ) );
     setFocusProxy( de );
     setSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Fixed );
 }
